@@ -12,7 +12,7 @@ from concurrent.futures import ThreadPoolExecutor
 
 from connect.client import AsyncConnectClient, ClientError
 from connect.eaas.runner.config import ConfigHelper
-from connect.eaas.runner.handlers.events import ExtensionHandler
+from connect.eaas.runner.handlers.events import EventsApp
 
 logger = logging.getLogger(__name__)
 
@@ -21,7 +21,7 @@ class TasksManagerBase(ABC):
     """
     Base class for Tasks managers.
     """
-    def __init__(self, config: ConfigHelper, handler: ExtensionHandler, enqueue):
+    def __init__(self, config: ConfigHelper, handler: EventsApp, enqueue):
         self.config = config
         self.handler = handler
         self.enqueue = enqueue
@@ -59,10 +59,12 @@ class TasksManagerBase(ABC):
                 installation = await self.get_installation(task_data)
             method_name = self.get_method_name(task_data, argument)
             method = self.handler.get_method(
+                task_data.input.event_type,
                 task_data.options.task_id,
                 method_name,
                 installation=installation,
                 api_key=task_data.options.api_key,
+                connect_correlation_id=task_data.options.connect_correlation_id,
             )
             if not method:
                 async with self.lock:
